# In this script I create a function for various rounding guidelines

# I follow APA conventions

# Means, SD rounded to 1 decimal place
# F-values, t values, chi-squares rounded to 2 decimal places

# P.value function ----

# p values reported as follows
# < .001 ~ "< .001"
# < .01 rounded to 3 decimal places
# < .05 but > .045 gets reported to 3 decimal places, because it affects
    # interpretation of significance
# > .01 rounded to 2 decimal places

P.round <- function(x) {
  case_when(
  x < .001 ~ "< 0.001",
  x < .01  ~ as.character(round(x, digits = 3)),
  x < .05 & x > .045 ~ as.character(round(x, digits = 3)),
  x > .01  ~ as.character(round(x, digits = 2)))
}

# To remove leading zero
# 1- delete from "< .001"
# 2- IB_an$Pr <- str_replace(IB_an$Pr, "^0+" ,"")

# Means and SD function ----
MeanSD.round <- function(x){
  case_when(x < 0.05  ~ signif(x, digits = 1), # Print first non-zero value
            x >= 0.05 ~ round(x, digits = 1)) %>% 
    as.character(x) # Removes trailing zeroes
}

# F, T, and chi square function ----
FTChi.round <- function(x){
  case_when(x < 0.005 ~ signif(x, digits = 1), # Print first non-zero value
            x >= 0.005 ~ round(x, digits = 2)) %>%
    as.character(x) # Removes trailing zeroes
}

# Functions are saved in this script which we can then source in analyses

