# This script will process the data for the end of experiment soil salinity

# Load required packages ----
library(tidyverse) # for cleaning

# Load files ----
# set your working directory
setwd()
list.files()
SS <- read.csv("Greenhouse_Salinity_Soil.csv", header = T)
head(SS)

# We will read in the treatment location .csv, and combine it with this df
TL <- read.csv("Greenhouse_Treatment_Locations.csv", header = T)
head(TL)

# Rename Bucket column
TL <- TL %>% 
  rename("Bucket" = "ï..Number")

# Left join with SS
SS <- SS %>% 
  left_join(TL, by = "Bucket") %>% 
  mutate(Bucket = as.factor(Bucket))

table(SS$Bucket, SS$Position) # Check for two samples from each bucket
levels(SS$Bucket) # Check for 126 Buckets total 

# Calculate ECe for each sample
# ECe = EC1:5 * (g water added/70% of soil volume)
SS <- SS %>% 
  group_by(Bucket, Position) %>% 
  mutate(ECe = EC.microS.cm * (Water.Weight / 
                                 (.70 * Soil.Volume.mL)),
         ECe = ECe / 1000) # Convert to dS/m from microS/cm

# Change order of factor levels
SS <- SS %>% 
  mutate(Salinity = case_when(Salinity == "FRESH" ~ "Fresh",
                              Salinity == "MED" ~ "Medium",
                              Salinity == "HIGH" ~ "High"),
         Salinity = factor(Salinity, levels = c("Fresh", "Medium", "High")),
         Water_Level = case_when(Water_Level == "D" ~ "Drought",
                                 Water_Level == "S" ~ "Saturated"),
         Position = case_when(Position == "T" ~ "Top of Pot",
                              Position == "B" ~ "Bottom of Pot"),
         Position = factor(Position, levels = c("Top of Pot", "Bottom of Pot")))

# Change class of columns ----
sapply(SS, class)

# Factor Columns
facCols <- c("Bucket", "Position", "Seed_Mix", "Salinity", "Water_Level", "ROW")
SS[facCols]<-lapply(SS[facCols], as.factor)

# Numeric Columns
numCols <- c("Soil.Weight", "Water.Weight", "PSU", "EC.microS.cm", "Temp", 
             "Soil.Volume.mL", "ECe")
SS[numCols] <- lapply(SS[numCols], as.numeric)

# Time Columns we will leave as is. Not necessary for graphing
# Check classes again
sapply(SS, class)

# Reduce DF to necessary cols
SS <- SS %>% 
  select(Bucket:Position, Seed_Mix:Water_Level, ECe)


# Save dataframe ----
setwd("../Processed_Data")

save(SS, file = "DF_Salinity-Soil.RData")




